@@ -168,6 +168,8 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
             video = self.getPiH264Relay(id)
             audio = None
+            loop = asyncio.new_event_loop()
+            asyncio.set_event_loop(loop)
 
             transceiver = pc.addTransceiver("video", direction="sendonly")
 
@@ -235,10 +237,10 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
                     answer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
 
-                    async def setremotedescription(pc):
+                    async def setremotedescription():
                         await self.peerConnections[id].setRemoteDescription(answer)
 
-                    syncify_async_function(setremotedescription())
+                    asyncio.run(setremotedescription())
 
         @self.sio.event
         def disconnectBroadcaster(id, desc):
